From: Jiadong Zhu <jiadong....@amd.com>

PMFW will handle the features disablement properly for gpu reset case,
driver involvement may cause some unexpected issues.

Signed-off-by: Jiadong Zhu <jiadong....@amd.com>
---
 drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c 
b/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c
index 7c3356d6da5e..ace71abbbcf6 100644
--- a/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c
+++ b/drivers/gpu/drm/amd/pm/swsmu/amdgpu_smu.c
@@ -1677,13 +1677,14 @@ static int smu_disable_dpms(struct smu_context *smu)
        }
 
        /*
         * For SMU 13.0.4/11, PMFW will handle the features disablement properly
disablement properly
         * for gpu reset and S0i3 cases. Driver involvement is unnecessary.
         */
        if (amdgpu_in_reset(adev) || adev->in_s0ix) {
                switch (amdgpu_ip_version(adev, MP1_HWIP, 0)) {
                case IP_VERSION(13, 0, 4):
                case IP_VERSION(13, 0, 11):
+               case IP_VERSION(14, 0, 0):
                        return 0;
                default:
                        break;
@@ -1677,13 +1677,14 @@ static int smu_disable_dpms(struct smu_context *smu)
 
        /*
-        * For SMU 13.0.4/11, PMFW will handle the features disablement properly
+        * For SMU 13.0.4/11 and 14.0.0, PMFW will handle the features 
disablement properly
         * for gpu reset and S0i3 cases. Driver involvement is unnecessary.
-- 
2.25.1

Reply via email to